@@ -23,6 +23,7 @@ class DATA_SUBTYPES:
     # CATEGORICAL
     SINGLE = 'Binary Category'
     MULTIPLE = 'Category'
+    TAGS = 'Tags'
 
     # FILE_PATH
     IMAGE = 'Image'
@@ -49,7 +50,7 @@ class DATA_TYPES:
 DATA_TYPES_SUBTYPES = {
     DATA_TYPES.NUMERIC: [DATA_SUBTYPES.INT, DATA_SUBTYPES.FLOAT, DATA_SUBTYPES.BINARY],
     DATA_TYPES.DATE: [DATA_SUBTYPES.DATE, DATA_SUBTYPES.TIMESTAMP],
-    DATA_TYPES.CATEGORICAL: [DATA_SUBTYPES.SINGLE, DATA_SUBTYPES.MULTIPLE],
+    DATA_TYPES.CATEGORICAL: [DATA_SUBTYPES.SINGLE, DATA_SUBTYPES.MULTIPLE, DATA_SUBTYPES.TAGS],
     DATA_TYPES.FILE_PATH: [DATA_SUBTYPES.IMAGE, DATA_SUBTYPES.VIDEO, DATA_SUBTYPES.AUDIO],
     DATA_TYPES.SEQUENTIAL: [DATA_SUBTYPES.ARRAY],
     DATA_TYPES.TEXT: [DATA_SUBTYPES.SHORT, DATA_SUBTYPES.RICH],
