@@ -298,11 +298,13 @@ class DataAnalyzer(BaseModule):
                         outliers = lof_outliers(data_subtype, col_data)
                         stats_v2[col_name]['outliers'] = {
                             'outlier_values': outliers,
-                            'outlier_buckets': compute_outlier_buckets(outlier_values=outliers,
-                                                                    hist_x=histogram['x'],
-                                                                    hist_y=histogram['y'],
-                                                                    percentage_buckets=percentage_buckets,
-                                                                    col_stats=stats_v2[col_name]),
+                            'outlier_buckets': compute_outlier_buckets(
+                                outlier_values=outliers,
+                                hist_x=histogram['x'],
+                                hist_y=histogram['y'],
+                                percentage_buckets=percentage_buckets,
+                                col_stats=stats_v2[col_name]
+                            ),
                             'description': """Potential outliers can be thought as the "extremes", i.e., data points that are far from the center of mass (mean/median/interquartile range) of the data."""
                         }
 
@@ -323,9 +325,17 @@ class DataAnalyzer(BaseModule):
             self.log.info(f'Finished analyzing column: {col_name} !\n')
 
             if data_type == DATA_TYPES.CATEGORICAL:
-                total = sum(histogram['y'])
-                stats_v2[col_name]['guess_probability'] = sum((v / total)**2 for v in histogram['y'])
-        
+                if data_subtype == DATA_SUBTYPES.TAGS:
+                    delimiter = self.transaction.lmd.get('tags_delimiter', ',')
+                    data = [[x.strip() for x in item.split(delimiter)] for item in col_data]
+                    stats_v2[col_name]['tag_hist'] = Counter()
+                    for arr in data:
+                        stats_v2[col_name]['tag_hist'].update(arr)
+                    stats_v2[col_name]['guess_probability'] = sum((v / len(data))**2 for v in stats_v2[col_name]['tag_hist'].values())
+                else:
+                    total = sum(histogram['y'])
+                    stats_v2[col_name]['guess_probability'] = sum((v / total)**2 for v in histogram['y'])
+
         self.transaction.lmd['data_preparation']['accepted_margin_of_error'] = self.transaction.lmd['sample_settings']['sample_margin_of_error']
 
         self.transaction.lmd['data_preparation']['total_row_count'] = len(input_data.data_frame)
